function obj = specan_connect(specan)
%SPECAN_CONNECT Verbindung zum Spektralanalysator aufbauen
%   Kommunikation erfolgt mit SCPI-Befehlen
%   input arguments
%       specan          Bezeichnung des zu verwendenden Spektralanalysators
%                       untersttzt werden
%                       'none'  fr Testzwecke, Messwerte werden aus Datei gelesen
%                       'zvl'   National Instruments GPIB board, board index 0, 
%                               Rohde&Schwarz ZVL mit Optionen K1, B5, B7, B10 und B22, 
%                               primary address 20, Messwerte werden in Datei geschrieben
%                       'fsq'   National Instruments GPIB board, board index 0, 
%                               Rohde&Schwarz FSQ, primary address 20,
%                               Messwerte werden in Datei geschrieben
%                       'fpc'   Rohde&Schwarz FPC1500 mit Option B22, 
%                               ber USB angeschlossen, Ressourcenname mittels
%                               instrhwinfo('visa','rs') ermitteln,
%                               Messwerte werden in Datei geschrieben
%                       'fpl'   National Instruments GPIB board, board index 0, 
%                               Rohde&Schwarz FPL mit Optionen B22, B10 und B5, 
%                               primary address 20, Messwerte werden in Datei geschrieben
%   output arguments
%       obj             Instrument Object
%
%   Instrument Control Toolbox 
%       S. 1-23 bis 1-24
%       S. 3-20
%
%   SCPI-Befehle 
%       *IDN?
%
%   05.09.2019          T. Weber    
%   13.12.2020          Untersttzung fr FPC1500 und FPL1003 hinzugefgt

switch specan
    case 'none'
        % Dummy Object erzeugen
        obj.Name = 'none';
 
        disp('no spectrum analyzer');
        
    case {'zvl','fsq','fpl'}
        % Verbindung herstellen, groes Timeout konfigurieren
        obj = gpib('ni',0,20,'Timeout',100,'Name',specan);
        fopen(obj);

        % Abfrage der Instrument Identification zum Prfen der Verbindung
        fprintf(obj,'*IDN?');
        disp(fscanf(obj));

    case 'fpc'
        obj = visa('rs','USB0::0x0AAD::0x01BB::102772::2::INSTR','InputBufferSize',2^18,'Timeout',100,'Name',specan);
        fopen(obj);
        
        % Abfrage der Instrument Identification zum Prfen der Verbindung
        fprintf(obj,'*IDN?');
        disp(fscanf(obj));

    otherwise
    	error('unsupported spectrum analyzer');
        
end

end
